@@ -13,7 +13,7 @@ use overload
     '@{}' => \&lines,
     '""' => \&stringify;
 
-our $VERSION = "0.5.71";
+our $VERSION = 0.5;
 
 sub new {
     my $proto = shift;
@@ -30,12 +30,6 @@ sub new {
     return $self;
 }
 
-sub DESTROY {
-  my $self = shift;
-  $_->{model} = undef for @{$self->lines};
-  $self = undef;
-}
-
 sub new_from_file {
     my $self = shift->new;
     my $file = shift || \*STDIN;
@@ -89,7 +83,7 @@ sub add {
 	push @{$self->{lines}}, $line;
     }
     $self->{tree}->{$line->part}->{$line->color}++;
-    $line->dir($self->dir);
+    $line->model($self);
 }
 
 sub splice {
@@ -215,13 +209,11 @@ sub Lego::Ldraw::build_tree {
     }
   }
   my $t;
-  $b = undef;
-  $d = undef;
-  $s = undef;
 }
 
 sub Lego::Ldraw::recurse_part_tree {
   my $tree = shift->copy;
+
   my ($b, $d, $s, $test) = @_;
   $test = $test || sub { shift->type == 1 };
 
@@ -237,10 +229,6 @@ sub Lego::Ldraw::recurse_part_tree {
       }
     }
   }
-  $b = undef;
-  $d = undef;
-  $s = undef;
-  $tree = undef;
 }
 
 1;
